import {hasUserConsents} from '@s-ui/consents'
import {getAdobeMarketingCloudVisitorIdFromWindow} from '@s-ui/segment-wrapper/lib/adobeRepository'
import Cookies from 'js-cookie'
import {v4 as uuid} from 'uuid'

const requiredConsents = [1, 8, 10]

function getDomain() {
  return window.location.host
    .split('.')
    .slice(-2)
    .join('.')
}

export function getVisitorId() {
  if (window.__mpi.visitorId) return Promise.resolve(window.__mpi.visitorId)

  // useractioncomplete when the user accepts or declines the consents
  // tcloaded when the user did already accept or decline the consents
  return new Promise(resolve => {
    window.__tcfapi('addEventListener', 2, async ({eventStatus}) => {
      const cookies = window.document.cookie
      const isEvent = ['useractioncomplete', 'tcloaded'].includes(eventStatus)
      // Filter out event if invalid or because of missing consents
      if (!isEvent) return
      // If has no consents resolve
      if (!hasUserConsents({requiredConsents, cookies})) return resolve()
      // Retrieve existing cookie or get a new one
      let visitorId = Cookies.get('IJ_MCMID')
      if (!visitorId) {
        visitorId = await getAdobeMarketingCloudVisitorIdFromWindow()
        if (!visitorId) visitorId = uuid()
      }

      // Domain must be saved without `www`
      Cookies.set('IJ_MCMID', visitorId, {
        expires: 365,
        domain: getDomain()
      })
      window.__mpi.visitorId = visitorId
      return resolve(visitorId)
    })
  })
}

export const setupSegmentWrapperConfig = () => {
  function getSite() {
    return window.location.host.indexOf('infojobs.it') > -1
      ? 'infojobs.it'
      : 'infojobs.net'
  }

  window.__mpi = {
    ...window.__mpi, // test purposes only
    segmentWrapper: {
      facebookPixelId: 283351338713870,
      googleAdsPixelId: 1024323628,
      defaultProperties: {
        site: getSite()
      },
      getCustomAdobeVisitorId: getVisitorId,
      tcfTrackDefaultProperties: {
        vertical: 'jobs'
      }
    }
  }
}
